==> eiffelstudio-18.11.10.2592.tar: F_code/C5/ew241.c <==
/*
 * Code for class EW_COMPILE_PRECOMPILED_INST
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ew241.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {EW_COMPILE_PRECOMPILED_INST}.compilation_options */
static EIF_REFERENCE F760_4266_body (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
#define Result RTOTRR
	RTOUDR(218)

	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("compilation_options", 759, Current, 0, 1, 9016);
	RTGC;
	RTOTP;
	RTHOOK(1);
	{
		static EIF_TYPE_INDEX typarr0[] = {645,894,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 645, _OBJSIZ_1_1_0_1_0_0_0_0_);
	}
	F646_3682(RTCW(tr1), ((EIF_INTEGER_32) 1L));
	Result = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	tr1 = RTMS32_EX_H("-\000\000\000v\000\000\000e\000\000\000r\000\000\000b\000\000\000o\000\000\000s\000\000\000e\000\000\000",8,1123198821);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R2579[Dtype(Result)-509])(RTCW(Result), tr1);
	RTHOOK(3);
	tr1 = RTMS32_EX_H("-\000\000\000p\000\000\000r\000\000\000e\000\000\000c\000\000\000o\000\000\000m\000\000\000p\000\000\000i\000\000\000l\000\000\000e\000\000\000",11,2086473829);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R2579[Dtype(Result)-509])(RTCW(Result), tr1);
	RTOTE;
	RTHOOK(4);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F760_4266 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	return RTOUCR(218,F760_4266_body,(Current,arg1));
}

void EIF_Minit241 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C5/ew241.c <==
/*
 * Code for class EW_COMPILE_PRECOMPILED_INST
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ew241.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {EW_COMPILE_PRECOMPILED_INST}.compilation_options */
static EIF_REFERENCE F760_4273_body (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
#define Result RTOTRR
	RTOUDR(218)

	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("compilation_options", 759, Current, 0, 1, 9023);
	RTGC;
	RTOTP;
	RTHOOK(1);
	{
		static EIF_TYPE_INDEX typarr0[] = {645,894,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 645, _OBJSIZ_1_1_0_1_0_0_0_0_);
	}
	F646_3689(RTCW(tr1), ((EIF_INTEGER_32) 1L));
	Result = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	tr1 = RTMS32_EX_H("-\000\000\000v\000\000\000e\000\000\000r\000\000\000b\000\000\000o\000\000\000s\000\000\000e\000\000\000",8,1123198821);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R2581[Dtype(RTCW(Result))-625])(Result, tr1);
	RTHOOK(3);
	tr1 = RTMS32_EX_H("-\000\000\000p\000\000\000r\000\000\000e\000\000\000c\000\000\000o\000\000\000m\000\000\000p\000\000\000i\000\000\000l\000\000\000e\000\000\000",11,2086473829);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R2581[Dtype(RTCW(Result))-625])(Result, tr1);
	RTOTE;
	RTHOOK(4);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F760_4273 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	return RTOUCR(218,F760_4273_body,(Current,arg1));
}

void EIF_Minit241 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
